@@ -318,15 +318,24 @@ sub run {
             my $second_version = $entries[1]->Version;
             if ($first_version and $second_version) {
                 tag 'latest-debian-changelog-entry-without-new-version'
-                  unless versions_gt(
-                    $first_version =~ s/^([^:]+)://r,
-                    $second_version =~ s/^([^:]+)://r
-                  )
+                  unless versions_gt($first_version, $second_version)
                   or $entries[0]->Changes =~ /backport/i
                   or $entries[0]->Source ne $entries[1]->Source;
                 tag 'latest-debian-changelog-entry-changed-to-native'
                   if $native_pkg and $second_version =~ m/-/;
             }
+            my $first_version_without_epoch = $first_version =~ s/^([^:]+)://r;
+            foreach my $entry (@entries[1..$#entries]) {
+                my $version_without_epoch = $entry->Version =~ s/^([^:]+)://r;
+                if (    $first_version_without_epoch eq $version_without_epoch
+                    and $entries[0]->Source eq $entry->Source) {
+                    tag
+                      'latest-debian-changelog-entry-reuses-existing-version',
+                      "$first_version == $entry->{Version}",
+                      "(last used: $entry->{Date})";
+                    last;
+                }
+            }
 
             my $first_upstream = $first_version;
             $first_upstream =~ s/-[^-]+$//;
@@ -337,14 +346,16 @@ sub run {
             my $second_debian =substr $second_version,length($second_upstream);
             $second_debian =~ s/-([^-]+)$/$1/ if length($second_debian) > 0;
 
-            if ($first_upstream eq $second_upstream) {
+            if (    $first_upstream eq $second_upstream
+                and $entries[0]->Source eq $entries[1]->Source) {
                 if ($entries[0]->Changes
                     =~ /^\s*\*\s+new\s+upstream\s+(?:\S+\s+)?release\b/im) {
                     tag 'possible-new-upstream-release-without-new-version';
                 }
                 if ($first_debian =~ /^\d+$/ and $second_debian =~ /^\d+$/) {
                     unless ($first_debian == $second_debian + 1) {
-                        tag 'non-consecutive-debian-revision';
+                        tag 'non-consecutive-debian-revision',
+                          "$first_version -> $second_version";
                     }
                 }
             }
@@ -364,6 +375,13 @@ sub run {
                 tag 'epoch-change-without-comment',
                   "$second_epoch -> $first_epoch"
                   unless $entries[0]->Changes =~ /\bepoch\b/im;
+
+                my ($first_no_epoch) = ($first_upstream =~ s/^([^:]+)://r);
+                my ($second_no_epoch) = ($second_upstream =~ s/^([^:]+)://r);
+                tag
+                  'epoch-changed-but-upstream-version-did-not-go-backwards',
+                  "$first_no_epoch >= $second_no_epoch"
+                  unless versions_gt($second_no_epoch, $first_no_epoch);
             }
         }
 
@@ -484,7 +502,7 @@ sub run {
         for my $i (0 .. $#lines) {
             my $line = $i + $chloff;
             tag 'debian-changelog-line-too-short', $1, "(line $line)"
-              if $lines[$i] =~ /^   [*]\s(.{1,5})$/;
+              if $lines[$i] =~ /^   [*]\s(.{1,5})$/ and $1 !~ /:$/;
             if (length($lines[$i]) > 81
                 and $lines[$i] !~ /^[\s.o*+-]*(?:[Ss]ee:?\s+)?\S+$/) {
                 tag 'debian-changelog-line-too-long', "line $line";
