@@ -920,7 +920,7 @@ sub run {
                     tag 'binary-package-depends-on-toolchain-package',
                       "$field: $part_d_orig"
                       if $KNOWN_TOOLCHAIN->known($d_pkg)
-                      and $is_dep_field
+                      and &$is_dep_field($field)
                       and not $pkg =~ m/^dh-/
                       and not $pkg =~ m/-(source|src)$/
                       and not $DH_ADDONS_VALUES{$pkg};
@@ -1350,7 +1350,7 @@ sub run {
             }
             if ($uri =~ m{//(.+)\.debian\.org/}) {
                 tag 'vcs-deprecated-in-debian-infrastructure', "vcs-$vcs", $uri
-                  unless $1 =~ m{^(?:salsa|git\.dgit)$};
+                  unless $1 =~ m{^(?:salsa|.*\.dgit)$};
             } else {
                 tag 'orphaned-package-not-maintained-in-debian-infrastructure',
                   "vcs-$vcs", $uri
