@@ -38,7 +38,8 @@ my $LOCALE_CODES = Lintian::Data->new('files/locale-codes', qr/\s++/);
 my $INCORRECT_LOCALE_CODES
   = Lintian::Data->new('files/incorrect-locale-codes', qr/\s++/);
 my $MULTIARCH_DIRS = Lintian::Data->new('common/multiarch-dirs', qr/\s++/);
-my $GENERIC_PYTHON_MODULES= Lintian::Data->new('files/python-generic-modules');
+my $GENERIC_HEADER_FILES = Lintian::Data->new('files/generic-header-files');
+my $GENERIC_PYTHON_MODULES= Lintian::Data->new('files/generic-python-modules');
 
 my $PRIVACY_BREAKER_WEBSITES= Lintian::Data->new(
     'files/privacy-breaker-websites',
@@ -163,7 +164,7 @@ sub _load_file_package_list_mapping {
 }
 
 my $JS_EXT
-  = '(?:(?i)[-._]?(?:compiled|lite|min|pack(?:ed)?|yc)?\.js(?:\.gz)?)$';
+  = '(?:(?i)[-._]?(?:compiled|lite|min|pack(?:ed)?|prod|umd|yc)?\.js(?:\.gz)?)$';
 my $PHP_EXT = '(?i)\.(?:php|inc|dtd)$';
 my @FILE_PACKAGE_MAPPING = (
     _load_file_package_list_mapping(
@@ -309,6 +310,12 @@ sub run {
     my $multiarch_dir = $MULTIARCH_DIRS->value($arch);
     my $ppkg = quotemeta($pkg);
 
+    my %header_dirs = ('usr/include/' => 1);
+    foreach my $x ($MULTIARCH_DIRS->all) {
+        my $dir = $MULTIARCH_DIRS->value($x);
+        $header_dirs{"usr/include/$dir/"} = 1;
+    }
+
     # get the last changelog timestamp
     # if for some weird reasons the timestamp does
     # not exist, it will remain 0
@@ -600,8 +607,16 @@ sub run {
         }
         # ---------------- /usr
         elsif ($fname =~ m,^usr/,) {
-            # ---------------- /usr/share/doc
-            if ($fname =~ m,^usr/share/doc/\S,) {
+            # ---------------- /usr/include
+            if ($fname =~ m,^usr/include/,) {
+                if ($file->is_file and $header_dirs{$file->dirname}) {
+                    for my $regex ($GENERIC_HEADER_FILES->all) {
+                        tag 'header-has-overly-generic-name', $fname,
+                          if $file->basename =~ m,$regex,i;
+                    }
+                }
+                # ---------------- /usr/share/doc
+            } elsif ($fname =~ m,^usr/share/doc/\S,) {
                 if ($type eq 'udeb') {
                     tag 'udeb-contains-documentation-file', $file;
                 } else {
@@ -1290,7 +1305,7 @@ sub run {
             and not $fname =~ m{ \. (?:
                   # Common "non-license" file extensions...
                    el|[ch]|cc|p[ylmc]|[hu]i|p_hi|html|php|rb|xpm
-                     |png|jpe?g|gif|svg|dtd|mk|lisp|yml|rs
+                     |png|jpe?g|gif|svg|dtd|mk|lisp|yml|rs|ogg
                ) \Z}xsm
             and not $fname=~ m,^usr/share/zope/Products/.*\.(?:dtml|pt|cpt)$,
             and not $fname =~ m,/under\S+License\.docbook$,
@@ -2092,6 +2107,15 @@ sub _check_tag_url_privacy_breach {
         return;
     }
 
+    # In Mallard XML, <link> is a clickable anchor that will not be
+    # followed automatically.
+    if(    $file->basename =~ '.xml$'
+        && $tagattr eq 'link'
+        && $file->file_contents
+        =~ qr{ xmlns="http://projectmallard\.org/1\.0/"}) {
+        return;
+    }
+
     # track well known site
     foreach my $breaker ($PRIVACY_BREAKER_WEBSITES->all) {
         my $value = $PRIVACY_BREAKER_WEBSITES->value($breaker);
@@ -2186,7 +2210,7 @@ sub detect_privacy_breach {
 
     while (my $block = $sfd->readwindow) {
         # Strip comments
-        for my $x (qw(<!--.*?--\s*> /\*.*?\*/)) {
+        for my $x (qw(<!--(?!\[if).*?--\s*> /\*(?!@cc_on).*?\*/)) {
             $block =~ s@$x@@gs;
         }
         # try generic fragment tagging
