@@ -27,6 +27,7 @@ use List::MoreUtils qw(any none);
 
 use Lintian::Tags qw(tag);
 use Lintian::Relation qw(:constants);
+use Lintian::Relation::Version qw(versions_lte);
 
 my @FIELDS = qw(Depends Pre-Depends Recommends Suggests);
 my @IGNORE = qw(-dev$ -docs?$ -common$ -tools$);
@@ -47,6 +48,9 @@ my %MISMATCHED_SUBSTVARS = (
     '^python2?-.+' => '${python3:Depends}',
 );
 
+my $VERSIONS = Lintian::Data->new('python/versions', qr/\s*=\s*/o);
+my @VERSION_FIELDS = qw(x-python-version xs-python-version x-python3-version);
+
 sub run {
     my ($pkg, $type, $info) = @_;
 
@@ -99,6 +103,58 @@ sub _run_source {
         }
     }
 
+    foreach my $field (@VERSION_FIELDS) {
+        my $pyversion = $info->source_field($field);
+        next unless defined($pyversion);
+
+        my @valid = (
+            ['\d+\.\d+', '\d+\.\d+'],['\d+\.\d+'],
+            ['\>=\s*\d+\.\d+', '\<\<\s*\d+\.\d+'],['\>=\s*\d+\.\d+'],
+            ['current', '\>=\s*\d+\.\d+'],['current'],
+            ['all']);
+
+        my @pyversion = split(/\s*,\s*/, $pyversion);
+
+        if ($pyversion =~ m/^current/) {
+            tag 'python-version-current-is-deprecated', $field;
+        }
+
+        if (@pyversion > 2) {
+            if (any { !/^\d+\.\d+$/ } @pyversion) {
+                tag 'malformed-python-version', $field, $pyversion;
+            }
+        } else {
+            my $okay = 0;
+            for my $rule (@valid) {
+                if (
+                    $pyversion[0] =~ /^$rule->[0]$/
+                    && ((
+                               $pyversion[1]
+                            && $rule->[1]
+                            && $pyversion[1] =~ /^$rule->[1]$/
+                        )
+                        || (!$pyversion[1] && !$rule->[1]))
+                  ) {
+                    $okay = 1;
+                    last;
+                }
+            }
+            tag 'malformed-python-version', $field, $pyversion unless $okay;
+        }
+
+        if ($pyversion =~ /\b(([23])\.\d+)$/) {
+            my ($v, $major) = ($1, $2);
+            my $old = $VERSIONS->value("stable-python$major");
+            my $ancient = $VERSIONS->value("oldstable-python$major");
+
+            if (versions_lte($v, $ancient)) {
+                tag 'ancient-python-version-field', $field, $v;
+            } elsif (versions_lte($v, $old)) {
+                tag 'old-python-version-field', $field, $v;
+            }
+        }
+    }
+
     return;
 }
 
