@@ -30,7 +30,7 @@ use constant {
     WC_TYPE_DECENDANTS => 'DECENDANTS',
 };
 
-use List::MoreUtils qw(any);
+use List::MoreUtils qw(any none);
 use Text::Levenshtein qw(distance);
 
 use Lintian::Relation::Version qw(versions_compare);
@@ -86,11 +86,8 @@ sub run {
     return;
 }
 
-# Note that we allow people to use "https://" even the
-# policy says it must be "http://".  It might be
-# pedantically wrong, but it is not worth arguing over On
-# the plus side, it gives security to people blindly
-# copy-wasting the URLs using "https://".
+# The policy states, since 4.0.0, that people should use "https://" for the
+# format URI. This is checked later in check_dep5_copyright.
 # return undef is not dep5 and '' if unknown version
 sub _find_dep5_version {
     my ($original_uri) = @_;
@@ -164,8 +161,12 @@ sub _check_apache_notice_files {
     return if not @notice_files;
 
     foreach my $binpkg (@procs) {
-        my @files = $binpkg->info->sorted_index;
-        return if any { $_->basename =~ m/^NOTICE(\.gz)?$/} @files;
+        my @files = map { $_->name } $binpkg->info->sorted_index;
+        my $java_info = $binpkg->info->java_info;
+        for my $jar_file (sort keys %{$java_info}) {
+            push @files, keys %{$java_info->{$jar_file}{files}};
+        }
+        return if any { m{/NOTICE(\.txt)?(\.gz)?$} } @files;
     }
 
     tag 'missing-notice-file-for-apache-license', join(' ', @notice_files);
@@ -178,6 +179,12 @@ sub _check_dep5_copyright {
     my $contents = $copyright_path->file_contents;
     my (@dep5, @lines);
 
+    if (    $contents =~ m/^Files-Excluded:/
+        and $contents
+        !~ m{^Format:.*/doc/packaging-manuals/copyright-format/1.0$}) {
+        tag 'files-excluded-without-copyright-format-1.0';
+    }
+
     if (
         $contents !~ m{
                (?:^ | \n)
@@ -189,6 +196,7 @@ sub _check_dep5_copyright {
                  | VERSIONED_FORMAT_URL
                ) }x
       ){
+
         tag 'no-dep5-copyright';
         return;
     }
@@ -220,6 +228,8 @@ sub _check_dep5_copyright {
         tag 'unversioned-copyright-format-uri', $uri;
     }elsif (versions_compare $version, '<<', $dep5_last_normative_change) {
         tag 'out-of-date-copyright-format-uri', $uri;
+    }elsif ($uri =~ m,^http://www\.debian\.org/,) {
+        tag 'insecure-copyright-format-uri', $uri;
     }
 
     if (versions_compare $version, '<<', $dep5_last_overhaul) {
@@ -266,21 +276,26 @@ sub _parse_dep5 {
         }
     }
     check_files_excluded($info, $first_para->{'files-excluded'} // '');
-    if (    not defined $first_para->{'format'}
-        and not defined $first_para->{'format-specification'}){
-        tag 'missing-field-in-dep5-copyright', 'format',
-          "(line $lines[0]{'format'})";
-    }
 
-    my (undef, $full_license_header, undef,@short_licenses_header)
+    tag 'missing-field-in-dep5-copyright', 'format',
+      "(line $lines[0]{'format'})"
+      if none { defined $first_para->{$_} } qw(format format-specification);
+    tag 'missing-explanation-for-contrib-or-non-free-package'
+      if $info->source_field('section', '') =~ m{^(contrib|non-free)(/.+)?$}
+      and none { defined $first_para->{$_} } qw(comment disclaimer);
+    tag 'missing-explanation-for-repacked-upstream-tarball'
+      if $info->repacked
+      and none { defined $first_para->{$_} } qw(comment files-excluded);
+
+    my (undef, $full_license_field, undef,@short_licenses_field)
       =parse_license($first_para->{'license'}, 1);
-    for my $short_license (@short_licenses_header) {
+    for my $short_license (@short_licenses_field) {
         $required_standalone_licenses{$short_license} = 0
-          if not defined($full_license_header);
+          if not defined($full_license_field);
         $short_licenses_seen{$short_license}          = 1;
     }
-    if(defined($full_license_header)) {
-        for (@short_licenses_header) {
+    if(defined($full_license_field)) {
+        for (@short_licenses_field) {
             $standalone_licenses{$_} = -1;
             $full_licenses_seen{$_} = 1;
         }
@@ -342,6 +357,10 @@ sub _parse_dep5 {
                   "paragraph at line $current_line)";
             }
 
+            tag 'global-files-wildcard-not-first-paragraph-in-dep5-copyright',
+              "(paragraph at line $current_line)"
+              if $files eq '*' and $i > 1;
+
             # Files paragraph
             if (not @commas_in_files and $files =~ /,/) {
                 @commas_in_files = ($i, $files_fname);
@@ -419,7 +438,7 @@ sub _parse_dep5 {
                         if(defined($full_licenses_seen{$_})
                             and $_ ne 'public-domain') {
                             tag 'dep5-copyright-license-name-not-unique',
-                              "(paragraph at line $current_line)";
+                              $_, "(paragraph at line $current_line)";
                         } else {
                             $full_licenses_seen{$_} = $current_line;
                         }
