@@ -444,7 +444,8 @@ sub _fetch_index_data {
         # Note this cannot ever be 100% reliable as the filename might contain
         # "fake" dates.
         ($perm,$ownership,$size,$date,$time,$name)
-          = $line=~ /^(.{10}) (.*?) (\d+) ([-\d]{10}) ([:\d]{5,8}) (.*)$/;
+          = $line
+          =~ /^(.{10}) (.*?) (\d+) ([-\d]{10}) ([:\d]{5,8}(?:.\d+)?) (.*)$/;
         croak "cannot parse tar output from $index: $line"
           unless defined $perm;
         $ownership =~ s/\s+$//;
